@@ -7,10 +7,10 @@ import threading
 import typing
 
 from gi.repository import GLib
-from zxcvbn import zxcvbn
+from zxcvbn_rs_py import zxcvbn
 
 if typing.TYPE_CHECKING:
-    from typing import Callable
+    from collections.abc import Callable
 
 
 def generate(
@@ -69,7 +69,7 @@ def generate(
         if use_numbers and not any(c.isdigit() for c in password):
             correct = False
 
-        if use_symbols and not any(c.isalpha() for c in password):
+        if use_symbols and not any(not c.isalnum() for c in password):
             correct = False
 
         if correct:
@@ -86,12 +86,12 @@ def strength(password: str) -> int:
     :rtype: int
     """
     if password:
-        return zxcvbn(password)["score"]
+        return int(zxcvbn(password).score)
 
     return 0
 
 
-def _threaded_compute_strenght(password: str, callback: Callable[[int], None]) -> None:
+def _threaded_compute_strength(password: str, callback: Callable[[int], None]) -> None:
     score = strength(password)
     GLib.idle_add(callback, score)
 
@@ -99,7 +99,7 @@ def _threaded_compute_strenght(password: str, callback: Callable[[int], None]) -
 def strength_async(password: str, callback: Callable[[int], None]) -> None:
     if password:
         thread = threading.Thread(
-            target=_threaded_compute_strenght,
+            target=_threaded_compute_strength,
             args=[password, callback],
         )
         thread.daemon = True
