@@ -16,6 +16,8 @@ if TYPE_CHECKING:
     from gsecrets.database_manager import DatabaseManager
     from gsecrets.utils import LazyValue
 
+NOT_INIT = "Provider not initialized."
+
 
 class YubiKeyInfo(GObject.Object):
     __gtype_name__ = "YubiKeyInfo"
@@ -54,12 +56,12 @@ class YubiKeyInfo(GObject.Object):
 
 
 class YubiKeyProvider(BaseProvider):
-    def __init__(self, _window):
+    def __init__(self, _window: Adw.Window) -> None:
         super().__init__()
 
-        self.active_key: YubiKeyInfo = None
-        self.unlock_row: Adw.ComboRow = None
-        self.create_row: Adw.ComboRow = None
+        self.active_key: YubiKeyInfo | None = None
+        self.unlock_row: Adw.ComboRow | None = None
+        self.create_row: Adw.ComboRow | None = None
 
         # NOTE: There is currently a bug which prevents yubikey rescan
         # running under flatpak, that's why we can simply collect all yubikeys
@@ -133,9 +135,14 @@ class YubiKeyProvider(BaseProvider):
         return model
 
     def create_unlock_widget(self, database_manager: DatabaseManager) -> Gtk.Widget:
+        factory = Gtk.SignalListItemFactory()
+        factory.connect("setup", self._on_factory_setup)
+        factory.connect("bind", self._on_factory_bind)
+
         row = Adw.ComboRow()
         row.set_title(_("YubiKey"))
         row.set_subtitle(_("Select key"))
+        row.set_factory(factory)
         row.connect("notify::selected", self._on_unlock_row_selected)
         self.unlock_row = row
 
@@ -143,6 +150,7 @@ class YubiKeyProvider(BaseProvider):
         refresh_button.set_valign(Gtk.Align.CENTER)
         refresh_button.add_css_class("flat")
         refresh_button.set_icon_name("view-refresh-symbolic")
+        # TRANSLATORS YubiKey is a proper name key, see https://en.wikipedia.org/wiki/YubiKey.
         refresh_button.set_tooltip_text(_("Select YubiKey slot"))
         refresh_button.connect("clicked", self._on_refresh_button_clicked)
         row.add_suffix(refresh_button)
@@ -177,22 +185,25 @@ class YubiKeyProvider(BaseProvider):
     def _on_factory_bind(self, _factory, list_item):
         label = list_item.get_child()
         info = list_item.get_item()
-        info.bind_property("label", label, "label", GObject.BindingFlags.SYNC_CREATE)
+        label.props.label = info.props.label
 
     def _on_refresh_button_clicked(self, _row: Adw.ComboRow) -> None:
         model = self._create_model()
 
-        factory = Gtk.SignalListItemFactory()
-        factory.connect("setup", self._on_factory_setup)
-        factory.connect("bind", self._on_factory_bind)
+        if self.unlock_row is None:
+            raise ValueError(NOT_INIT)
 
-        self.unlock_row.set_factory(factory)
         self.unlock_row.set_model(model)
         self.unlock_row.set_selected(len(model) - 1)
 
     def create_database_row(self) -> None:
+        factory = Gtk.SignalListItemFactory()
+        factory.connect("setup", self._on_factory_setup)
+        factory.connect("bind", self._on_factory_bind)
+
         self.create_row = Adw.ComboRow()
         self.create_row.set_title(_("YubiKey"))
+        self.create_row.set_factory(factory)
         self.create_row.connect("notify::selected", self._on_create_row_selected)
 
         refresh_button = Gtk.Button()
@@ -220,11 +231,9 @@ class YubiKeyProvider(BaseProvider):
     def _on_yubikey_create_refresh_button_clicked(self, _button: Gtk.Button) -> None:
         model = self._create_model()
 
-        factory = Gtk.SignalListItemFactory()
-        factory.connect("setup", self._on_factory_setup)
-        factory.connect("bind", self._on_factory_bind)
+        if self.create_row is None:
+            raise ValueError(NOT_INIT)
 
-        self.create_row.set_factory(factory)
         self.create_row.set_model(model)
         self.create_row.set_selected(0)
 
@@ -262,4 +271,7 @@ class YubiKeyProvider(BaseProvider):
         return False
 
     def config(self) -> dict:
+        if self.active_key is None:
+            raise ValueError(NOT_INIT)
+
         return {"serial": self.active_key.serial, "slot": self.active_key.slot}
